@@ -12,7 +12,6 @@ OC.L10N.register(
     "News folders" : "Naujienų aplankai",
     "An RSS/Atom feed reader" : "RSS/Atom kanalų skaitytuvė",
     "Use system cron for updates" : "Atnaujinimams naudoti sistemos planuoklę (cron)",
-    "Purge interval" : "Išvalymo intervalas",
     "Maximum read count per feed" : "Didžiausias kanalo straipsnių kiekis",
     "Maximum redirects" : "Daugiausiai peradresavimų",
     "How many redirects the feed fetcher should follow." : "Kiek kartų kanalų gaviklis turėtų sekti paskui peradresavimus.",
@@ -31,8 +30,10 @@ OC.L10N.register(
     "Share" : "Bendrinti",
     "Username" : "Naudotojo vardas",
     "No users found" : "Nerasta jokių naudotojų",
+    "Error while searching for users" : "Klaida ieškant naudotojų",
     "by" : " ",
     "from" : "iš",
+    "shared by" : "bendrina",
     "Play audio" : "Groti",
     "Download audio" : "Atsisiųsti garso įrašą",
     "Download video" : "Atsisiųsti vaizdo įrašą",
